%global srcname azure-storage
%global common_description This project provides a client library in Python that makes it easy to consume\
Microsoft Azure Storage services.

%global _with_python2 0%{?rhel} || 0%{?fedora} <= 29
%global py2_prefix %{?rhel:python}%{?fedora:python2}
# Tests require a more recent version of requests library than the one available
# in Fedora <= 28 and EL
%global _with_py2_tests 0%{?fedora} >= 29
# Some Python 3 libraries required by azure-storage are not available in EL
%global _with_python3 0%{?fedora}
# Tests don't support Python >= 3.7
%global _with_py3_tests 0%{?fedora} <= 28
# EL is missing some dependencies to build documentation
%global _with_doc 0%{?fedora}
%global pydoc_prefix %{?rhel:python}%{?fedora:python%{python3_pkgversion}}
%global sphinxbuild sphinx-build%{?fedora:-%{python3_version}}

%global azure_sdk_min_version 4.0.0

Name:           python-%{srcname}
Version:        1.4.0
Release:        1%{?dist}
Summary:        Microsoft Azure Storage Library for Python

License:        MIT
URL:            https://github.com/Azure/azure-storage-python
Source0:        %{url}/archive/v%{version}-file/%{srcname}-%{version}.tar.gz

%if 0%{?_with_python2}
BuildRequires:  %{py2_prefix}-setuptools
BuildRequires:  %{py2_prefix}-devel
%if 0%{?_with_py2_tests}
BuildRequires:  %{py2_prefix}-azure-sdk >= %{azure_sdk_min_version}
BuildRequires:  %{py2_prefix}-cryptography
BuildRequires:  %{py2_prefix}-dateutil
BuildRequires:  %{py2_prefix}-futures
BuildRequires:  %{py2_prefix}-requests
%if 0%{?fedora} <= 27
BuildRequires:  python-vcrpy
%else
BuildRequires:  %{py2_prefix}-vcrpy
%endif
%endif
%endif
%if 0%{?_with_python3}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
%if 0%{?_with_py3_tests}
BuildRequires:  python%{python3_pkgversion}-azure-sdk >= %{azure_sdk_min_version}
BuildRequires:  python%{python3_pkgversion}-cryptography
BuildRequires:  python%{python3_pkgversion}-dateutil
BuildRequires:  python%{python3_pkgversion}-requests
BuildRequires:  python%{python3_pkgversion}-vcrpy
%endif
%endif
%if 0%{?_with_doc}
BuildRequires:  %{pydoc_prefix}-azure-sdk >= %{azure_sdk_min_version}
BuildRequires:  %{pydoc_prefix}-cryptography
BuildRequires:  %{pydoc_prefix}-dateutil
%if 0%{?rhel}
BuildRequires:  %{pydoc_prefix}-futures
%endif
BuildRequires:  %{pydoc_prefix}-pip
BuildRequires:  %{pydoc_prefix}-requests
BuildRequires:  %{pydoc_prefix}-sphinx
%endif
BuildArch:      noarch

%description
%{common_description}


%if 0%{?_with_python2}
%package -n python2-%{srcname}
Summary:        %{summary}
Requires:       %{py2_prefix}-azure-sdk >= %{azure_sdk_min_version}
Requires:       %{py2_prefix}-cryptography
Requires:       %{py2_prefix}-dateutil
Requires:       %{py2_prefix}-futures
Requires:       %{py2_prefix}-requests
%{?python_provide:%python_provide python2-%{srcname}}

%description -n python2-%{srcname}
%{common_description}
%endif


%if 0%{?_with_python3}
%package -n python%{python3_pkgversion}-%{srcname}
Summary:        %{summary}
Requires:       python%{python3_pkgversion}-azure-sdk >= %{azure_sdk_min_version}
Requires:       python%{python3_pkgversion}-cryptography
Requires:       python%{python3_pkgversion}-dateutil
Requires:       python%{python3_pkgversion}-requests
%{?python_provide:%python_provide python%{python3_pkgversion}-%{srcname}}

%description -n python%{python3_pkgversion}-%{srcname}
%{common_description}
%endif


%if 0%{?_with_doc}
%package doc
Summary:        Documentation for %{name}

%description doc
%{common_description}

This package provides documentation for %{name}.
%endif


%prep
%autosetup -p0 -n azure-storage-python-%{version}%{?prerelease}-file


%build
for package in azure-storage-nspkg azure-storage-common azure-storage-blob azure-storage-file azure-storage-queue; do
    pushd $package
%if 0%{?_with_python2}
    %py2_build
%endif
%if 0%{?_with_python3}
    %py3_build
%endif
    popd
done

%if 0%{?_with_doc}
%make_build -C doc/ html SPHINXBUILD=%{sphinxbuild}
rm doc/_build/html/.buildinfo
%endif


%install
for package in azure-storage-nspkg azure-storage-common azure-storage-blob azure-storage-file azure-storage-queue; do
    pushd $package
%if 0%{?_with_python2}
    %py2_install
%endif
%if 0%{?_with_python3}
    %py3_install
%endif
    popd
done


%check
PYTHONPATH=
for d in azure-*/; do
    PYTHONPATH+="$d:"
done
export PYTHONPATH=${PYTHONPATH%:}

%if 0%{?_with_python2} && 0%{_with_py2_tests}
%{__python2} -m unittest discover
%endif
%if 0%{?_with_python3} && 0%{_with_py3_tests}
%{__python3} -m unittest discover
%endif


%if 0%{?_with_python2}
%files -n python2-%{srcname}
%doc BreakingChanges.md ChangeLog.md README.rst
%license LICENSE.txt
%{python2_sitelib}/*
%endif


%if 0%{?_with_python3}
%files -n python%{python3_pkgversion}-%{srcname}
%doc BreakingChanges.md ChangeLog.md README.rst
%license LICENSE.txt
%{python3_sitelib}/*
%endif


%if 0%{?_with_docs}
%files doc
%doc doc/_build/html/
%license LICENSE.txt
%endif


%changelog
* Wed Apr 24 2019 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.4.0-1
- Update to 1.4.0

* Fri Nov 23 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.3.1-2
- Improve unit test checks
- Fix license tag
- Build documentation with Python 3 on Fedora

* Mon Aug 06 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.3.1-1
- Update to 1.3.1
